[gatein-commits] gatein SVN: r2028 - portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation.
do-not-reply at jboss.org
do-not-reply at jboss.org
Sun Mar 7 22:58:30 EST 2010
Author: mwringe
Date: 2010-03-07 22:58:29 -0500 (Sun, 07 Mar 2010)
New Revision: 2028
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/PageNavigationUtils.java
Log:
GTNPORTAL-820: fix issues in which empty navigation nodes would not be saved properly. Needed to updated the navigation util filter to return an empty node if the acceptNonDisplatedNode is set.
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/PageNavigationUtils.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/PageNavigationUtils.java 2010-03-08 02:50:14 UTC (rev 2027)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/PageNavigationUtils.java 2010-03-08 03:58:29 UTC (rev 2028)
@@ -225,8 +225,8 @@
}
}
- //If the node has no child and it does not point to any Page, then null is return
- if (filteredChildren.size() == 0 && cloneStartNode.getPageReference() == null)
+ //If are only accepting displayed nodes and If the node has no child and it does not point to any Page, then null is return
+ if (!acceptNonDisplayedNode && filteredChildren.size() == 0 && cloneStartNode.getPageReference() == null)
{
return null;
}
More information about the gatein-commits
mailing list